## Installation
tfkit is tested on Python 3.6+, and PyTorch 1.1.0+.  

### Installing via pip
```bash
pip install tfkit
```
### Installing via source
```bash
git clone https://github.com/voidful/tfkit.git
python setup.py install
```

## Running tfkit

Once you've installed tfkit, you can run with  

### pip installed version: 
`tfkit-train`   
`tfkit-eval`   
`tfkit-dump`   

### local version: 
`python -m tfkit.train`   
`python -m tfkit.eval`    
`python -m tfkit.dump`    